@@ -1025,6 +1025,7 @@ struct option long_options[] = {
 	{"shrink-normal", 0, 0, '2'},
 	{"shrink-extra", 0, 0, '3'},
 	{"shrink-insane", 0, 0, '4'},
+	{"iter", 1, 0, 'i'},
 
 	{"scroll-square", 1, 0, 'S'},
 	{"scroll", 1, 0, 's'},
@@ -1042,7 +1043,7 @@ struct option long_options[] = {
 };
 #endif
 
-#define OPTIONS "zlLxa:01234s:S:rencCfqvhV"
+#define OPTIONS "zlLxa:01234i:s:S:rencCfqvhV"
 
 void version()
 {
@@ -1062,10 +1063,11 @@ void usage()
 	cout << "  " SWITCH_GETOPT_LONG("-a, --add F MNG PNG...", "-a    ") "  Create a .MNG file at F frame/s from .PNG files" << endl;
 	cout << "Options:" << endl;
 	cout << "  " SWITCH_GETOPT_LONG("-0, --shrink-store    ", "-0    ") "  Don't compress" << endl;
-	cout << "  " SWITCH_GETOPT_LONG("-1, --shrink-fast     ", "-1    ") "  Compress fast" << endl;
-	cout << "  " SWITCH_GETOPT_LONG("-2, --shrink-normal   ", "-2    ") "  Compress normal" << endl;
-	cout << "  " SWITCH_GETOPT_LONG("-3, --shrink-extra    ", "-3    ") "  Compress extra" << endl;
-	cout << "  " SWITCH_GETOPT_LONG("-4, --shrink-insane   ", "-4    ") "  Compress extreme" << endl;
+	cout << "  " SWITCH_GETOPT_LONG("-1, --shrink-fast     ", "-1    ") "  Compress fast (zlib)" << endl;
+	cout << "  " SWITCH_GETOPT_LONG("-2, --shrink-normal   ", "-2    ") "  Compress normal (7z)" << endl;
+	cout << "  " SWITCH_GETOPT_LONG("-3, --shrink-extra    ", "-3    ") "  Compress extra (7z)" << endl;
+	cout << "  " SWITCH_GETOPT_LONG("-4, --shrink-insane   ", "-4    ") "  Compress extreme (zopfli)" << endl;
+	cout << "  " SWITCH_GETOPT_LONG("-i N, --iter=N        ", "-i    ") "  Compress iterations" << endl;
 	cout << "  " SWITCH_GETOPT_LONG("-s, --scroll NxM      ", "-s NxM") "  Enable the scroll optimization with a NxM pattern" << endl;
 	cout << "  " SWITCH_GETOPT_LONG("                      ", "      ") "  search. from -Nx-M to NxM. Example: -s 4x6" << endl;
 	cout << "  " SWITCH_GETOPT_LONG("-S, --scroll-square N ", "-S N  ") "  Enable the square scroll optimization with a NxN pattern" << endl;
@@ -1090,7 +1092,8 @@ void process(int argc, char* argv[])
 
 	opt_quiet = false;
 	opt_verbose = false;
-	opt_level = shrink_normal;
+	opt_level.level = shrink_normal;
+	opt_level.iter = 0;
 	opt_reduce = false;
 	opt_expand = false;
 	opt_noalpha = false;
@@ -1152,20 +1155,23 @@ void process(int argc, char* argv[])
 				throw error() << "Invalid frequency";
 			} break;
 		case '0' :
-			opt_level = shrink_none;
+			opt_level.level = shrink_none;
 			opt_force = true;
 			break;
 		case '1' :
-			opt_level = shrink_fast;
+			opt_level.level = shrink_fast;
 			break;
 		case '2' :
-			opt_level = shrink_normal;
+			opt_level.level = shrink_normal;
 			break;
 		case '3' :
-			opt_level = shrink_extra;
+			opt_level.level = shrink_extra;
 			break;
 		case '4' :
-			opt_level = shrink_extreme;
+			opt_level.level = shrink_insane;
+			break;
+		case 'i' :
+			opt_level.iter = atoi(optarg);
 			break;
 		case 's' : {
 			int n;
